@@ -41,7 +41,7 @@ class ScanRunner(object):
                     exit(-1)
                 else:
                     print('Failed to get scan data from server: ' +
-                        result['message'])
+                        str(result['message']))
                     exit(-1)
 
             cls.aws_config = result['awsConfig']
@@ -190,8 +190,8 @@ class ScanRunner(object):
                 file_empty = True
             
             if not file_empty:
-                timestampe = Utils.upload_output(cls.aws_config, str(cls.app_number_id), str(scan_data['scanId']), output_file)
-                scan_data['timestamp'] = timestampe
+                Utils.upload_output(cls.aws_config, str(cls.app_number_id), str(scan_data['scanId']), output_file)
+                scan_data['timestamp'] = str(scan_data['scanId'])
                 scan_data['fileEmpty'] = False
             else:
                 scan_data['fileEmpty'] = True
@@ -214,11 +214,7 @@ class ScanRunner(object):
             print(str(e))
             # S3 error found, set the current running data item to ERROR
             scan_data['status'] = STATUS_ERROR
-
-            if e.server_message is not None:
-                scan_data['errorMessage'] = e.server_message
-            else:
-                scan_data['errorMessage'] = e.cli_message
+            scan_data['errorMessage'] = str(e)
 
             cls.do_etl()
 
