@@ -43,6 +43,8 @@ class Utils(object):
 	etl_waiting_threshold = 300
 	# docker container exit code 137: Indicates failure as container received SIGKILL
 	container_exit_code_kill = 137
+	# retrying upload to s3
+	upload_retry = False
 
 	@classmethod
 	def get_retryable_http(cls):
@@ -460,7 +462,14 @@ class Utils(object):
 		
 			print('Output file uploaded')
 		except Exception as e:
-			raise S3Error('Failed to upload output file: ' + str(e))
+			# retry one more time
+			if not cls.upload_retry:
+				print('Failed to upload output file, retrying. ' + str(e))
+				cls.upload_retry = True
+				return cls.upload_output(aws_config, app_id, scan_id, output_file)
+			else:
+				cls.upload_retry = False
+				raise S3Error('Failed to upload output file: ' + str(e))
 		finally:
 			try:
 				if output_file_handle is not None:
